# Changelog — rptar

## v0.1.3 (2025-10-05)

- Added Python 3.14 to supported versions.

## v0.1.2 (2025-03-22)

- Added Python 3.13 to supported versions.
- Fixed a type error related to `repro_tarfile.open` when running static typechecking against repro_tarfile v0.2.0 or higher.

## v0.1.1 (2024-02-02)

- Fixed typo in package description.

## v0.1.0 (2024-02-02)

Initial release! 🎉
